@@ -38,7 +38,7 @@ Note to developers looking into the code: The overview of the `SlabsIter` class:
 """
 
 
-from typing import Callable, Mapping, Iterable, Union, NewType, Any
+from typing import Callable, Mapping, Iterable, Union, NewType, Any, MutableMapping
 from i2 import Sig, ContextFanout
 
 
@@ -67,8 +67,9 @@ DFLT_INTERRUPT_EXCEPTIONS = (StopIteration, IteratorExit, KeyboardInterrupt)
 DoNotBreak = type('DoNotBreak', (), {})
 do_not_break = DoNotBreak()
 do_not_break.__doc__ = (
-    'A sentinel that exception handlers can use to indicate that iteration should '
-    'continue -- the default for exception handling is to break out of the iteration.'
+    'Sentinel that should be used to signal SlabsIter iteration not to break. '
+    'This sentinel should be returned by exception handlers if they want to tell '
+    'the iteration not to stop (in all other cases, the iteration will stop)'
 )
 
 IgnoredOutput = Any
@@ -140,7 +141,7 @@ def _handle_exception(
     )
 
 
-def _call_from_dict(kwargs: dict, func: Callable, sig: Sig):
+def _call_from_dict(kwargs: MutableMapping, func: Callable, sig: Sig):
     """A i2.call_forgivingly optimized for our purpose
 
     The sig argument needs to be the Sig(func) to work correctly.
@@ -305,6 +306,8 @@ class SlabsIter:
 
     """
 
+    _output_of_context_enter = None
+
     def __init__(self, handle_exceptions=DFLT_INTERRUPT_EXCEPTIONS, **components):
         self.components = components
         self.handle_exceptions = _get_handle_exceptions(handle_exceptions)
@@ -313,8 +316,9 @@ class SlabsIter:
             name: Sig.sig_or_default(func) for name, func in self.components.items()
         }
         self.context = ContextFanout(**components)
+        # assert all(map(callable, self.components)), "components need to all be callable"
 
-    def _call_on_scope(self, scope: Mapping):
+    def _call_on_scope(self, scope: MutableMapping):
         """Calls the components 1 by 1, sourcing inputs and writing outputs in scope"""
         # for each component
         for name, component in self.components.items():
@@ -345,19 +349,20 @@ class SlabsIter:
                         self.exit_value = handler_output  # remember, in case useful
                         break
 
-    def __enter__(self):
+    def open(self):
         self._output_of_context_enter = self.context.__enter__()
         return self
 
-    def __exit__(self, exc_type=None, exc_val=None, exc_tb=None) -> None:
+    def close(self, exc_type=None, exc_val=None, exc_tb=None) -> None:
         return self._output_of_context_enter.__exit__(exc_type, exc_val, exc_tb)
 
-    def __call__(self):
+    def run(self):
         for _ in self:
             pass
 
-    open = __enter__  # convenience alias
-    close = __exit__  # convenience alias
+    __enter__ = open
+    __exit__ = close
+    __call__ = run
 
     def dot_digraph(self):
         from i2 import Sig
